﻿-- clcInfo_ArmsWarrior templates.lua -- Deronda
-- same as with the options, add this in a loader function
clcInfo.optionsCMLoaders[#(clcInfo.optionsCMLoaders) + 1] = function()
    -- don't load if class is wrong
    local _, class = UnitClass("player")
    if class ~= "WARRIOR" then return end
    
    local mod = clcInfo_Options.templates
    local defs = mod.defs
    local format = string.format
    
    local spells = {
        ["Heroic Strike"]	       = 78,
        ["Inner Rage"]		       = 1134,
        ["Recklessness"]           = 1719,
        ["Deadly Calm"]		       = 85730,
        ["Battle Trance"]          = 12964,
        ["Incite"]                 = 86627,
        ["Colossus Smash"]         = 86346,
        --enraged buffs
        ["Berserker Rage"]	       = 18499,
        ["Enrage"]                 = 13046,
        --armor debuffs
        ["Corrosive Spit"]         =35387,
        ["Tear Armor"]             =50498,
        ["Expose Armor"]           =8647,
        ["Faerie Fire"]            =770,
        ["Sunder Armor"]           =7386,
        --attack speed slow debuffs
        ["Dust Cloud"]             =50285,
        ["Tailspin"]               =90314,
        ["Earth Shock"]            =8042,
        ["Frost Fever"]            =59921,
        ["Infected Wounds"]        =48484,
        ["Judgements of the Just"] =53696,
        ["Thunder Clap"]           =6343,
        ["Waylay"]                 =51696,
        --phys damage reduction debuffs
        ["Curse of Weakness"]      =702,
        ["Demoralizing Roar"]      =99,
        ["Demoralizing Roar - Pet"]=50256,
        ["Demoralizing Screech"]   =24423,
        ["Demoralizing Shout"]     =1160,
        ["Scarlet Fever"]          =81132,
        ["Vindication"]            =26016,
    }
    -- get the real names
    local name
    for key, value in pairs(spells) do
        local name = GetSpellInfo(value)
        if not name then name = "Unknown Spell" end
        spells[key] = { id = value, name = name }
    end
    
    -- all
    --------------------------------------------------------------------------------
    --In many cases it is better to judge the use of these abilities based on expected rage generation, rather than current rage.
    --Unfortunately that cant be coded in.
    -- Heroic Strike if:
    --    rage >=85 AND target health>= 20
    --    OR deadly calm 
    --    OR battle_trance
    --    OR (incite OR colossus_smash) AND ((rage >=50 AND target health >=20) OR 
    --                                       (rage >=75 AND target health < 20))
    name = spells["Heroic Strike"].name
    mod:Add("icons", defs.CLASS_1, name, format([[
    local visible, texture, start, duration, enable, reversed, count, alpha = IconSpell("%s", true, ready)
    local rage = UnitPower("player")
    local deadly_calm = IconAura("HELPFUL|PLAYER", "player", "%s")
    local battle_trance = IconAura("HELPFUL|PLAYER", "player", "%s")
    local incite = IconAura("HELPFUL|PLAYER", "player", "%s")
    local colossus_smash = IconAura("HARMFUL|TARGET", "target", "%s")
    local target_health = floor(UnitHealth("target") / UnitHealthMax("target") * 100)
    if (rage >= 85 and target_health >= 20) or (deadly_calm == true) or (battle_trance == true) or ((incite == true or colossus_smash == true) and ((rage >= 50 and target_health >= 20) or (rage >= 75 and target_health < 20))) then
        return visible, texture, start, duration, enable, reversed, count, alpha 
    else
        return false, texture, start, duration, enable, reversed, count, alpha
    end]], name, spells["Deadly Calm"].name, spells["Battle Trance"].name,
    spells["Incite"].name, spells["Colossus Smash"].name)
    )
    
    -- Inner Rage > 80 rage and Deadly Calm not up and not available for 15
    name = spells["Inner Rage"].name
    mod:Add("icons", defs.CLASS_1, name, format([[
    local visible, texture, start, duration, enable, reversed, count, alpha = IconSpell("%s", true, ready)
    local deadly_calm = IconAura("HELPFUL|PLAYER", "player", "%s")
    local dc_start, dc_duration, _ = GetSpellCooldown(%d)
    local deadly_calm_cd = dc_start + dc_duration - GetTime()
    if deadly_calm == nil and UnitPower("player") > 80 and deadly_calm_cd > 15 then
        return visible, texture, start, duration, enable, reversed, count, alpha 
    else
        return false, texture, start, duration, enable, reversed, count, alpha
    end]], name, spells["Deadly Calm"].name, spells["Deadly Calm"].id)
    )
    
    -- Deadly Calm
    -- Turn icon red if rage is >= 30
    name = spells["Deadly Calm"].name
    mod:Add("icons", defs.CLASS_1, name, format([[
    local visible, texture, start, duration, enable, reversed, count, alpha = IconSpell("%s", true, ready)
    if UnitPower("player") < 30 then
        return visible, texture, start, duration, enable, reversed, count, alpha
    else
        return visible, texture, start, duration, enable, reversed, count, alpha, true, 0.8, 0.3, 0.3, 1
    end   
    ]], name))
    
    -- Recklessness
    name = spells["Recklessness"].name
    mod:Add("icons", defs.CLASS_1, name, format([[
    return IconSpell("%s")
    ]], name))

    --Enraged buff
    mod:Add("icons", defs.CLASS_1, "Enraged Buff", format([[
    return IconMAura("HELPFUL|PLAYER", "player", "%s", "%s")
    ]], spells["Berserker Rage"].name, spells["Enrage"].name))
    
    -- Armor debuff
    mod:Add("icons", defs.CLASS_1, "Armor Debuff", format([[
    return IconMAura("HARMFUL", "target", "%s", "%s", "%s", "%s", "%s")
    ]], spells["Corrosive Spit"].name, spells["Tear Armor"].name,
    spells["Expose Armor"].name, spells["Faerie Fire"].name,
    spells["Sunder Armor"].name))
    
    -- Attack speed debuff
    mod:Add("icons", defs.CLASS_1, "Attack Speed Debuff", format([[
    return IconMAura("HARMFUL", "target", "%s", "%s", "%s", "%s", "%s", "%s", "%s", "%s")
    ]], spells["Dust Cloud"].name, spells["Tailspin"].name,
    spells["Earth Shock"].name, spells["Frost Fever"].name,
    spells["Infected Wounds"].name, spells["Judgements of the Just"].name,
    spells["Thunder Clap"].name, spells["Waylay"].name))
    
    -- Physical damage debuff
    mod:Add("icons", defs.CLASS_1, "Physical Damage Debuff", format([[
    return IconMAura("HARMFUL", "target", "%s", "%s", "%s", "%s", "%s", "%s", "%s")
    ]], spells["Curse of Weakness"].name, spells["Demoralizing Roar"].name,
    spells["Demoralizing Roar - Pet"].name, spells["Demoralizing Screech"].name,
    spells["Demoralizing Shout"].name, spells["Scarlet Fever"].name,
    spells["Vindication"].name))
    
    -- arms
    --------------------------------------------------------------------------------
    -- Arms Rotation
    mod:Add("icons", defs.CLASS_1, "Arms Rotation Current Ability", 'return IconArmsCurrent()')
    mod:Add("icons", defs.CLASS_1, "Arms Rotation Next Ability", 'IconArmsNext()')
    -- Cooldown tracking for abilities
   
end